@@ -1,5 +1,7 @@
 # frozen_string_literal: true
 
+require 'addressable'
+
 module Fog
   module Compute
     class Aliyun
@@ -10,7 +12,7 @@ module Fog
           sigNonce = randonStr
           time = Time.new.utc
 
-          parameters = defalutParameters(action, sigNonce, time)
+          parameters = defaultParameters(action, sigNonce, time)
           pathUrl = defaultAliyunUri(action, sigNonce, time)
 
           parameters['SecurityGroupId'] = securitygroup_id
@@ -19,7 +21,7 @@ module Fog
 
           parameters['DestCidrIp'] = destCidrIp
           pathUrl += '&DestCidrIp='
-          pathUrl += URI.encode(destCidrIp, '/[^!*\'()\;?:@#&%=+$,{}[]<>`" ')
+          pathUrl += Addressable::URI.encode_component(destCidrIp, Addressable::URI::CharacterClasses::UNRESERVED + '|')
           nicType ||= 'intranet'
           parameters['NicType'] = nicType
           pathUrl += '&NicType='
@@ -29,7 +31,7 @@ module Fog
           portRange ||= '-1/-1'
           parameters['PortRange'] = portRange
           pathUrl += '&PortRange='
-          pathUrl += URI.encode(portRange, '/[^!*\'()\;?:@#&%=+$,{}[]<>`" ')
+          pathUrl += Addressable::URI.encode_component(portRange, Addressable::URI::CharacterClasses::UNRESERVED + '|')
 
           protocol = option[:protocol]
           protocol ||= 'all'
