@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Fog
   module Compute
     class Aliyun
@@ -14,7 +16,7 @@ module Fog
           _sigNonce = randonStr
           _time = Time.new.utc
 
-          _parameters = defalutParameters(_action, _sigNonce, _time)
+          _parameters = defaultParameters(_action, _sigNonce, _time)
           _pathURL = defaultAliyunUri(_action, _sigNonce, _time)
 
           _parameters['InstanceId'] = server_id
@@ -28,14 +30,8 @@ module Fog
             method: 'GET',
             path: _pathURL
           )
-        end # def stop_server
-      end # class Real
-
-      class Mock
-        def stop_server(_server_id)
-          true
-        end # def stop_server
-      end # class Mock
-    end # class aliyun
-  end # module Compute
-end # module Fog
+        end
+      end
+    end
+  end
+end
